#!/bin/bash
# Copyright (C) 2004-2013 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
#
# This file is part of datasid
#
# collect-agent is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.

# set PREFIX
export PREFIX="$(readlink -f "$(dirname $0)/../")"

# run datasid-common.sh
source "$(readlink -f "$(dirname $0)")/datasid-common.sh" || exit 6

if test -z "${PREFIX}"; then
    date +"%F %T - ERROR: Prefix not set."
    exit 1
fi

restore_backup() {
    # Check if backup exists
    if ! test -f ".backup/.md5sum"; then
        date +"%F %T - ERROR: Backup does not exist!"
        return
    fi

    # Remove the corrupted files
    for file in $(cat .md5sum | awk '{print $2}')
    do
        rm -f "$file"
    done

    # Restore backup
    cd ".backup"
    for file in $(cat .md5sum | awk '{print $2}')
    do
        cp --parents -a "$file" "../"
    done
    cp ".md5sum" "../"
    cd ".."
}

# Change to PREFIX keeping track of current directory
PREVIOUSDIR="$(pwd)"
cd "${PREFIX}"

if ! test -f ".md5sum"; then
    date +"%F %T - WARNING: md5sum does not exist. Restoring backup."
    restore_backup
fi

if ! md5sum --check ".md5sum" > /dev/null 2>&1 ; then
    date +"%F %T - WARNING: Corrupted files detected. Restoring backup."
    restore_backup
fi

cd "$PREVIOUSDIR"

exit 0
