#!/bin/bash
# Copyright (C) 2004-2013 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
#
# This file is part of datasid
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.

# 0 - Success
# 1 - Error while loading configuration
# 2 - INEP not configured
# 3 - XML filename not defined
# 4 - Client not found or without execution permission
# 5 - Error while collecting network usage data
# 6 - Error while executing the client

# ------------------------------------------------------------------------------
# Function: elapsedTime
# Verify if $DELAY seconds have elapsed since agent last execution.
# Return true or false.
function elapsedTime()
{
    test -f "${DATADIR}/netlastexec" || return 0

    atSeconds=$(date +%s)
    oldSeconds=$(cat ${DATADIR}/netlastexec)

    (( (${atSeconds}-${oldSeconds}) >= ${DELAY} ))

    return $?
}

# ------------------------------------------------------------------------------
# Function: clientExec
# Execute client sender with all necessary parameters.
# The parameters are obtained from the global variables.
function clientExec()
{
    date +"%F %T - Sending network usage data to the server."

    ${CLIENT} $*
    error=$?

    if test ${error} -ne 0; then
        date +"%F %T - ERROR: while sending network usage data to the server."
        return ${error}
    fi
}

# ------------------------------------------------------------------------------

# set PREFIX
export PREFIX="$(readlink -f "$(dirname $0)/../")"

# run datasid-common.sh
source "$(readlink -f "$(dirname $0)")/datasid-common.sh" || exit 1

if test -z "${PREFIX}"; then
    date +"%F %T - ERROR: Prefix not set."
    exit 2
fi

PREVIOUS_TRAFFIC="${DATADIR}/previous"

exec >> ${LOGFILE} 2>&1

date +"%F %T - Start of network usage execution."

# Check if telecentroInfo is configured
if ! test -f ${CONFDIR}/telecentroInfo; then
	date +"%F %T - telecentroInfo not found in ${CONFDIR}/telecentroInfo, waiting configuration."
	exit 8
fi
		
# Collect and send system data if elapsed enough time or if it's the first
# execution of the agent
if elapsedTime && test -d "${PREVIOUS_TRAFFIC}"; then
    
     # Collect system data
    if ! ${PREFIX}/bin/datasid-xml-generator "${PREFIX}/network-scripts" "${DATADIR}/net-collect.xml"; then
        date +"%F %T - ERROR: Failed to collect system data."
        exit 4
    fi

    # Send collected data
    if ! ${PREFIX}/bin/datasid-client.sh --send-net-usage "${DATADIR}/net-collect.xml"; then
        date +"%F %T - ERROR: Failed to send collected data."
        exit 7
    fi

    # Record the current execution time to be used by elapsedTime()
    date +%s > ${DATADIR}/netlastexec
	
	# Remove data already sent
	rm -rf ${PREVIOUS_TRAFFIC}
	
fi

date +"%F %T - network usage terminated successfully."
exit 0
