-- This function populates the fact_net_usage table, based on the staging
-- area tables. This function should NOT be called directly.
CREATE OR REPLACE FUNCTION load_fact_net_usage() returns void as $$
DECLARE
	result RECORD;
	start_ts TIMESTAMP;
	total_rows INTEGER;
BEGIN

	-- getting initial timestamp
	start_ts = CLOCK_TIMESTAMP();

	-- getting the date limits
	SELECT max(contact_date) as max_date, min(contact_date) as min_date 
		INTO result from sa_net_usage;

	-- 
	INSERT INTO fact_net_usage (tl_id, dat_id, macaddr,
		collect_time, down_kbits, down_packages, up_kbits, up_packages)
	(SELECT tl_id, contact_date, macaddr, collect_time, down_kbits,
		down_packages, up_kbits, up_packages FROM sa_net_usage
		WHERE valid = '1')
	EXCEPT
	(SELECT tl_id, dat_id, macaddr, collect_time, down_kbits,
		down_packages, up_kbits, up_packages FROM fact_net_usage WHERE 
		dat_id >= result.min_date AND dat_id <= result.max_date);

	-- how many rows were inserted?
	GET DIAGNOSTICS total_rows = ROW_COUNT;

	-- logging
	INSERT INTO control (name, start_time, end_time, total) 
		VALUES ('loading net usage contact', start_ts, CLOCK_TIMESTAMP(), total_rows);

END;
$$ language plpgsql;
