-- This function loads data from OLTP tables into the dw. This is the 
-- only function that should be called directly. Run it once a day.
CREATE OR REPLACE FUNCTION load_dw() returns void as $$
BEGIN

	-- populating dim_date with next 10 years
	PERFORM populate_dim_date(CAST(extract(year FROM CURRENT_DATE) AS INTEGER) + 10);

	PERFORM load_dim_telecenter;

        -- loads the OLTP data into the staging area
        -- 'E'TL -> Extract
	PERFORM sa_create();

	-- validate, cast, sanitize, remove and log invalid data
	-- E'T'L -> Transform
	PERFORM sa_sanitize();

	-- ET'L' -> Load
	PERFORM load_dim_inventory();
	PERFORM load_fact_contact();
	PERFORM load_fact_net_usage();
	PERFORM load_aggr_availability();

	-- dropping staging area tables
	PERFORM sa_drop();
END;
$$ language plpgsql;
