CREATE OR REPLACE FUNCTION audit_city(machtype machine_type_enum, region_in text, state_in text, city_in text, base_date DATE DEFAULT CURRENT_DATE) RETURNS
	TABLE ("data_atual" text, "regiao" text, "aud_estado" varchar, "cidade" text, "telecentro" text, "instaladas" bigint, "nao_instaladas" integer) AS $$
BEGIN

	RETURN QUERY SELECT
		to_char(base_date, 'DD/MM/YYYY'),
		initcap(region),
		state,
		initcap(city),
		initcap(tl_name),
		COUNT(*),
		0
	FROM
		(SELECT
			DISTINCT
				f.tl_id as tl_id,
				t.name as tl_name,
				f.macaddr as macaddr,
				c.region as region,
				c.state as state,
				c.name as city
		FROM
			fact_contact f
		INNER JOIN
			dim_telecenter t
		ON
			f.tl_id = t.id
                INNER JOIN
                        dim_city c
                ON
                        t.cit_id = c.id
		WHERE
			machine_type = machtype AND c.region = upper(region_in) AND c.state = upper(state_in) AND c.name = upper(city_in) AND f.dat_id <= base_date
		) AS a
	GROUP BY
		region, state, city, tl_name;
END;
$$ language plpgsql;



CREATE OR REPLACE FUNCTION audit_no_agent_city(proj project_enum, region_in text, state_in text, city_in text, base_date DATE DEFAULT CURRENT_DATE) RETURNS
	TABLE ("data_atual" text, "regiao" text, "aud_estado" varchar, "cidade" text, "escola" text) AS $$
BEGIN

	RETURN QUERY SELECT
		to_char(base_date, 'DD/MM/YYYY'),
		initcap(c.region),
		c.state,
		initcap(c.name),
		initcap(s.name)
	FROM
		dim_school s
	INNER JOIN
		dim_city c
	ON
		s.cit_id = c.id
	LEFT JOIN
		(SELECT * FROM fact_contact WHERE dat_id <= base_date AND project = proj) AS f
	ON
		c.id = f.cit_id
	WHERE
		c.region = upper(region_in) AND c.state = upper(state_in) AND c.name = upper(city_in) AND f.cit_id is NULL;
END;
$$ language plpgsql;
