#!/usr/bin/python

import psycopg2
import sys
from datetime import date, timedelta
import unittest

# TODO: Unit tests

MACHINE_PEAK = 10000
DAYS = 3
MACHINE_DOUBLE_COMM_RATIO = 0.12
MACHINE_MULTI_COMM_RATIO = 0.02
MACHINE_DECREASE_RATIO = 1.1
MULTI_HD_TOTAL = 10
HD_MODEL = 'foo'
HD_SIZE = 100
HD_USED = 0
HD_EXTRA = 3
M_SUPERID = '0000000000024554'
TEMPLATE = "INSERT INTO telecenter_inventory (contact_date, machine_type, m_superid, macaddr, os_type, os_distro, os_kernel, processor, memory, disk1_model, disk1_size, disk1_used, disk2_model, disk2_size, disk2_used, extra_hds, ts) VALUES (%s, 0, %s, %s, 'Linux', 'Ubuntu 10.04.4 LTS', '2.6.35-25-generic', 'Intel(R) Celeron(R) CPU E1200  @', 160, '1016076 ST3160318AS_6VY4BK6R', 140, 5, %s, %s, %s, %s, %s);"
INITIAL_DATE = date(2012, 7, 1)

def machine_increase(num):
  return 10**num

#def clean_inventory(cur, machines):
  cur.execute('TRUNCATE telecenter_inventory;')
#  for i in range(machines):
#    mac = gen_macaddress(i)
#    cur.execute('''DELETE FROM fact_contact AS f USING dim_school AS d
#WHERE f.sch_id = d.id AND f.macaddr = %s AND d.inep = %s;''', (mac, INEP))
#    cur.execute('''DELETE FROM dim_inventory AS i USING dim_school AS s
#WHERE i.macaddr = %s AND s.id = i.sch_id AND s.inep = %s''', (mac, INEP))

def insert_data(cur):
    for day in range(DAYS):
        machines = machine_increase(day)
        refresh_machines(machines, day, cur)
    return max_machine(machines, DAYS - 1)

def toHex(integer):
  if integer < 16:
    return '0' +  hex(integer)[2:]
  else: return hex(integer)[2:]

def gen_macaddress(integer):
  integer += 1
  p1 = integer & 255
  p2 = (integer & 65535) >> 8
  p3 = (integer & 16777215) >> 16
  p4 = (integer & 2147483647) >> 24
  return  "00:00:"  + toHex(p4) + ":" + toHex(p3) + ":" + toHex(p2) + ":" + toHex(p1)

def refresh_machines(machines, day, cur):
  contact = INITIAL_DATE + timedelta(days = day)
  for i in updated_machines(machines, day):
    macaddr = gen_macaddress(i)
#        print "Mac {0}".format(macaddr)
    if i < MULTI_HD_TOTAL:
      cur.execute(TEMPLATE, (contact, macaddr, HD_MODEL, HD_SIZE, HD_USED, HD_EXTRA))
    else:
      cur.execute(TEMPLATE, (contact, macaddr, None, None, None, 0))

def max_machine(machines, day):
  return intround(machines / (MACHINE_DECREASE_RATIO * (day + 1)))

def intround(f):
  return int(round(f))

def updated_machines(machines, day):
  repetition = intround(machines * MACHINE_DOUBLE_COMM_RATIO)
  multi = intround(machines * MACHINE_MULTI_COMM_RATIO)
  i = 0
#  print "Repetition {0}, multi {1}".format(repetition, multi)
#  print "Max {0}".format(max_machine(machines, day))
  while i < max_machine(machines, day):
    if repetition > 0:
      repetition -= 1
      yield repetition
    elif multi > 0:
      multi -= 1
      yield multi
    else:
      yield i
      i += 1

def get_connection(dbname, user):
  return psycopg2.connect('dbname=' + dbname, 'user=' + user)

if __name__ == '__main__':
  if len(sys.argv) != 3:
    sys.exit("Usage: {0} <database> <user>".format(sys.argv[0]))
  connection = get_connection(sys.argv[1], sys.argv[2])
  cur = connection.cursor()
  count = insert_data(cur)
  print "Machines inserted {0}".format(count)
  connection.commit()
  clean_inventory(cur, count)
  connection.commit()
  connection.close()
